# -*- coding: utf-8 -*-
#
# This file is part of the E2RingSimulator project
#
# Copyright (C): 2024
#                Elettra - Sinctrone Trieste S.C.p.A.
#
# Distributed under the terms of the LGPL license.
# See LICENSE.txt for more info.
import tango
class ElementProxy(object):
    """
    auxiliary class for handling the read and refresh of strengths of magnets
    """
    def __init__(self, MagName, DevName,MagIdx, InitialStrength):
        self.strength = InitialStrength
        self.previous_strength = InitialStrength
        self.changed = False
        self.mag_index = MagIdx
        # self.simulator = simulator
        self.mag_name = MagName
        self.dev_name = DevName
        try:
            self.deviceProxy = tango.DeviceProxy(DevName)
            self.valid = True
        except tango.DevFailed as e:
            self.deviceProxy = None
            self.valid = False
            #self.simulator.error_stream("failed to create device proxy for %s ",self.Devname)
            #print("failed to create device proxy for %s ",self.dev_name)
            
    def read(self): # read from magnet device and update values
        if self.deviceProxy is None:
            return  # ignore device not present in Tango DB 
        try:
            self.strength = self.deviceProxy.strength
            self.valid = True # maybe che attribute vlidity ?
            if self.strength != self.previous_strength:
                self.changed = True
                self.previous_strength = self.strength
            else:
                self.changed = False
            #print(self.mag_name, self.strength)
        except tango.DevFailed as e:
            self.valid = False
        

class CorrectorProxy(object):
    """
    auxiliary class for handling the read and refresh of strength of corrector magnets
    """
    def __init__(self, MagName, DevName,MagIdx, InitialStrength):
        self.strength = InitialStrength
        self.previous_strength = InitialStrength
        self.changed = False
        self.mag_index = MagIdx
        # self.simulator = simulator
        self.mag_name = MagName
        self.dev_name = DevName
        self.hv = None  # selector (index) for setting KickAngle in at.Corrector H=0, V=1 
        try:
            self.deviceProxy = tango.DeviceProxy(DevName)
            self.valid = True
            typ = self.deviceProxy.get_property('Type') # a correctly configured correcotr device has Type prpoert indicating H or V
            chan=typ['Type'][0]
            if chan == 'H':
                self.hv = 0
            if chan == 'V':
                self.hv = 1
        except tango.DevFailed as e:
            self.deviceProxy = None
            self.valid = False
            #self.simulator.error_stream("failed to create device proxy for %s ",self.Devname)
            #print("failed to create device proxy for %s ",self.dev_name)
            
    def read(self): # read from magnet device and update values
        if self.deviceProxy is None:
            return  # ignore device not present in Tango DB 
        try:
            self.strength = self.deviceProxy.strength
            self.valid = True # maybe che attribute vlidity ?
            if self.strength != self.previous_strength:
                self.changed = True
                self.previous_strength = self.strength
            else:
                self.changed = False
            #print(self.mag_name, self.strength)
        except tango.DevFailed as e:
            self.valid = False
